/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  Authors : Benjamin GAUTHIER - 24 Mar 2004
 *            Joseph BANINO
 *            Olivier JACQUES
 *            Richard GAYRAUD
 *            From Hewlett Packard Company.
 *           
 */

#include "sipp.hpp"

void CAction::afficheInfo()
{
    if(M_lookingPlace == E_LP_MSG)
      printf("Type[%d] - where[%s] - checkIt[%d] - varId[%d]",
             M_action,
             "Full Msg",
             M_checkIt,
		       M_varId);
    else
      printf("Type[%d] - where[%s-%s] - checkIt[%d] - varId[%d]",
             M_action,
             "Header",
             M_lookingChar,
             M_checkIt,
		       M_varId);
}


CAction::T_ActionType   CAction::getActionType()   { return(M_action);       }
CAction::T_VarType      CAction::getVarType()      { return(M_varType);      }
CAction::T_LookingPlace CAction::getLookingPlace() { return(M_lookingPlace); }

bool           CAction::getCheckIt()      { return(M_checkIt);      }
int            CAction::getVarId()        { return(M_varId);        }
char*          CAction::getLookingChar()  { return(M_lookingChar);  }

void CAction::setActionType   (CAction::T_ActionType   P_value) 
{ M_action       = P_value; }  
void CAction::setVarType      (CAction::T_VarType      P_value) 
{ M_varType      = P_value; }  
void CAction::setLookingPlace (CAction::T_LookingPlace P_value) 
{ M_lookingPlace = P_value; }
void CAction::setCheckIt      (bool           P_value) 
{ M_checkIt      = P_value; }
void CAction::setVarId        (int            P_value) 
{ M_varId        = P_value; }

void CAction::setLookingChar  (char*          P_value)
{
  if(M_lookingChar != NULL)
  {
    delete [] M_lookingChar;
    M_lookingChar = NULL;
  }

  if(P_value != NULL)
  { 
    M_lookingChar = new char[strlen(P_value)+1];
    strcpy(M_lookingChar, P_value);
  }
}


void CAction::setAction(CAction P_action)
{
  setActionType   ( P_action.getActionType()   );
  setVarType      ( P_action.getVarType()      );
  setLookingPlace ( P_action.getLookingPlace() );
  setVarId        ( P_action.getVarId()        );
  setLookingChar  ( P_action.getLookingChar()  );
  setCheckIt      ( P_action.getCheckIt()      );
}

CAction::CAction()
{
  M_action       = E_AT_NO_ACTION;
  M_varId        = 0;
  M_varType      = E_VT_UNDEFINED;
  M_checkIt      = false;
  M_lookingPlace = E_LP_MSG;
  M_lookingChar  = NULL;
}

CAction::CAction(const CAction &P_action)
{
  M_lookingChar = NULL;

  setActionType   ( P_action.M_action       );
  setVarType      ( P_action.M_varType      );
  setLookingPlace ( P_action.M_lookingPlace );
  setVarId        ( P_action.M_varId        );
  setLookingChar  ( P_action.M_lookingChar  );
  setCheckIt      ( P_action.M_checkIt      );
}  

CAction::~CAction()
{
  if(M_lookingChar != NULL)
  {
    delete [] M_lookingChar;
    M_lookingChar = NULL;
  }
}

/****************************** CActions class ************************/

void CActions::afficheInfo()
{
  printf("Action Max Size = [%d] - Action Current Setted[%d]\n", M_nbAction, M_currentSettedAction);
  for(int i=0; i<M_currentSettedAction; i++)
  {
    printf("actionlist[%d] : \n", i);
    M_actionList[i].afficheInfo();
  }
}

void CActions::reset()
{
  M_currentSettedAction = 0;
}

int CActions::getMaxSize()
{
  return(M_nbAction);
}

int CActions::getUsedAction()
{
  return(M_currentSettedAction);
}

void CActions::setAction(CAction P_action)
{
  if(M_currentSettedAction < M_nbAction)
  {
    M_actionList[M_currentSettedAction].setAction(P_action);
    M_currentSettedAction++;
  }
}

CAction* CActions::getAction(int i)
{
  if(i < M_currentSettedAction)
  {
    return(&M_actionList[i]);
  }
  else
    return(NULL);
}


// constructor and destructor

CActions::CActions(const CActions &P_actions)
{
    M_currentSettedAction = 0;
    M_nbAction = P_actions.M_currentSettedAction;
    M_actionList = new CAction[M_nbAction];
  
    for(int i=0; i<M_nbAction; i++)
	 {
      setAction(P_actions.M_actionList[i]);
	 }
}
  

CActions::CActions(int P_nbAction)
{
  M_nbAction = P_nbAction;
  M_currentSettedAction = 0;
  M_actionList = new CAction[P_nbAction];
}


CActions::~CActions()
{
  delete [] M_actionList;
  M_actionList = NULL;
}
